@@ -1,10 +1,10 @@
 var structspa__video__info =
 [
+    [ "media_type", "structspa__video__info.html#a73d52ad69db77b05afa52a8cb61455c9", null ],
+    [ "media_subtype", "structspa__video__info.html#a429e55f4dde148559d032bcaf8cd73f0", null ],
+    [ "raw", "structspa__video__info.html#a697a0106c54d5680d0cfd2731b60d712", null ],
     [ "dsp", "structspa__video__info.html#afe7b9fde171f232f0b7eb76778845784", null ],
     [ "h264", "structspa__video__info.html#ab2856db92b8c85f902b4be0390dd2141", null ],
-    [ "info", "structspa__video__info.html#a2b4797467940061e93ad79cbdbb9e928", null ],
-    [ "media_subtype", "structspa__video__info.html#a429e55f4dde148559d032bcaf8cd73f0", null ],
-    [ "media_type", "structspa__video__info.html#a73d52ad69db77b05afa52a8cb61455c9", null ],
     [ "mjpg", "structspa__video__info.html#a0e442291121d1e295e2db47ead38eb11", null ],
-    [ "raw", "structspa__video__info.html#a697a0106c54d5680d0cfd2731b60d712", null ]
+    [ "info", "structspa__video__info.html#a5807be036f8cf31b1b689208f1135ceb", null ]
 ];
\ No newline at end of file
